@@ -1,4 +1,4 @@
-# Copyright 2017 Red Hat, Inc.
+# Copyright 2017-2019 Red Hat, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -47,22 +47,30 @@ def is_lldptool_functional():
 
 def enable_lldp_on_iface(iface, rx_only=True):
     rc, out, err = cmd.exec_sync(
-        [LLDPTOOL, 'set-lldp', '-i', iface,
-         'adminStatus=' + ('rx' if rx_only else 'rxtx')])
+        [
+            LLDPTOOL,
+            'set-lldp',
+            '-i',
+            iface,
+            'adminStatus=' + ('rx' if rx_only else 'rxtx'),
+        ]
+    )
     if rc:
         raise EnableLldpError(rc, out, err, iface)
 
 
 def disable_lldp_on_iface(iface):
-    rc, out, err = cmd.exec_sync([LLDPTOOL, 'set-lldp', '-i', iface,
-                                  'adminStatus=disabled'])
+    rc, out, err = cmd.exec_sync(
+        [LLDPTOOL, 'set-lldp', '-i', iface, 'adminStatus=disabled']
+    )
     if rc:
         raise DisableLldpError(rc, out, err, iface)
 
 
 def is_lldp_enabled_on_iface(iface):
-    rc, out, err = cmd.exec_sync([LLDPTOOL, 'get-lldp', '-i', iface,
-                                  'adminStatus'])
+    rc, out, err = cmd.exec_sync(
+        [LLDPTOOL, 'get-lldp', '-i', iface, 'adminStatus']
+    )
     if rc:
         return False
     keyval = out.strip().split('=', 1)
@@ -90,9 +98,11 @@ def _parse_tlvs(text):
     for description, properties in _separate_tlvs(text):
         if description in TLVS_BY_DESCRIPTION:
             tlv = TLVS_BY_DESCRIPTION[description]
-            tlv_info = {'type': tlv.type,
-                        'name': tlv.name,
-                        'properties': tlv.parse_properties(properties)}
+            tlv_info = {
+                'type': tlv.type,
+                'name': tlv.name,
+                'properties': tlv.parse_properties(properties),
+            }
             if tlv.oui:
                 tlv_info['oui'] = tlv.oui
                 tlv_info['subtype'] = tlv.subtype
@@ -126,13 +136,15 @@ def _is_property_line(lines, line_number):
 
 class OUI(object):
     """ Organizationally Unique Identifier """
-    IEEE8021 = 0x0080c2
+
+    IEEE8021 = 0x0080C2
     IEEE8023 = 0x00120F
 
 
 class Tlv(object):
-    def __init__(self, tlv_type, oui, subtype, name, description,
-                 property_parser):
+    def __init__(
+        self, tlv_type, oui, subtype, name, description, property_parser
+    ):
         self.type = tlv_type
         self.oui = oui
         self.subtype = subtype
@@ -152,8 +164,10 @@ class PropertyParser(object):
 
     def _parse_subtype_value(self, property_line, tlv_name):
         tokens = property_line.split(':', 1)
-        return {'%s subtype' % tlv_name: tokens[0].strip(),
-                tlv_name: tokens[1].strip()}
+        return {
+            '%s subtype' % tlv_name: tokens[0].strip(),
+            tlv_name: tokens[1].strip(),
+        }
 
 
 class ChassisIdParser(PropertyParser):
@@ -173,8 +187,10 @@ class SingleStringPropertyParser(PropertyParser):
 
 class MultiStringPropertyParser(PropertyParser):
     def parse(self, tlv_name, property_lines):
-        return {k.lower(): v for k, v in
-                self._split_property_lines(property_lines).items()}
+        return {
+            k.lower(): v
+            for k, v in self._split_property_lines(property_lines).items()
+        }
 
     def _split_property_lines(self, lines):
         properties = {}
@@ -186,13 +202,16 @@ class MultiStringPropertyParser(PropertyParser):
 
 class ManagmentAddressParser(PropertyParser):
     def parse(self, tlv_name, property_lines):
-        properties = self._parse_subtype_value(property_lines[0],
-                                               'management address')
-        properties.update(self._parse_subtype_value(
-            property_lines[1], 'interface numbering'))
+        properties = self._parse_subtype_value(
+            property_lines[0], 'management address'
+        )
+        properties.update(
+            self._parse_subtype_value(property_lines[1], 'interface numbering')
+        )
         if len(property_lines) > 2:
-            properties['object identifier'] = property_lines[2].split(
-                ':', 1)[-1].strip()
+            properties['object identifier'] = (
+                property_lines[2].split(':', 1)[-1].strip()
+            )
         return properties
 
 
@@ -204,55 +223,119 @@ class PortVlanIdParser(PropertyParser):
 class VlanNameParser(PropertyParser):
     def parse(self, tlv_name, property_lines):
         tokens = property_lines[0].split(':', 1)
-        return {'VLAN ID': tokens[0].split(' ', 1)[-1].strip(),
-                'VLAN Name': tokens[1].strip()}
+        return {
+            'VLAN ID': tokens[0].split(' ', 1)[-1].strip(),
+            'VLAN Name': tokens[1].strip(),
+        }
 
 
 class LinkAggregationPropertyParser(PropertyParser):
     def parse(self, tlv_name, property_lines):
         port_id_tokens = property_lines[2].split(':', 1)
-        return {'Aggregation capable':
-                LinkAggregationPropertyParser._bool_from_line(
-                    property_lines[0]),
-                'Currently aggregated':
-                LinkAggregationPropertyParser._bool_from_line(
-                    property_lines[1]),
-                'Aggregated Port ID': port_id_tokens[-1].strip()}
+        pl0 = LinkAggregationPropertyParser._bool_from_line(property_lines[0])
+        pl1 = LinkAggregationPropertyParser._bool_from_line(property_lines[1])
+        return {
+            'Aggregation capable': pl0,
+            'Currently aggregated': pl1,
+            'Aggregated Port ID': port_id_tokens[-1].strip(),
+        }
 
     @staticmethod
     def _bool_from_line(line):
         return 'False' if 'not ' in line else 'True'
 
 
-TLVS = frozenset([
-    Tlv(1, 0, 0, 'Chassis ID', 'Chassis ID TLV', ChassisIdParser()),
-    Tlv(2, 0, 0, 'Port ID', 'Port ID TLV', PortIdParser()),
-    Tlv(3, 0, 0, 'Time to Live', 'Time to Live TLV',
-        SingleStringPropertyParser()),
-    Tlv(4, 0, 0, 'Port Description', 'Port Description TLV',
-        SingleStringPropertyParser()),
-    Tlv(5, 0, 0, 'System Name', 'System Name TLV',
-        SingleStringPropertyParser()),
-    Tlv(6, 0, 0, 'System Description', 'System Description TLV',
-        SingleStringPropertyParser()),
-    Tlv(7, 0, 0, 'System Capabilities', 'System Capabilities TLV',
-        MultiStringPropertyParser()),
-    Tlv(8, 0, 0, 'Management Address', 'Management Address TLV',
-        ManagmentAddressParser()),
-    Tlv(0x7f, OUI.IEEE8021, 1, 'Port VLAN ID', 'Port VLAN ID TLV',
-        PortVlanIdParser()),
-    Tlv(0x7f, OUI.IEEE8021, 3, 'VLAN Name', 'VLAN Name TLV',
-        VlanNameParser()),
-    # Because lldptool shows both Link Aggregation TLV in the same way,
-    # it is not possible to conclude from lldptool's output to the OUI and
-    # subtype. Here the Link Aggregation TLV is mapped to the IEEE8021
-    # Organizationally Specific TLV.
-    Tlv(0x7f, OUI.IEEE8021, 7, 'Link Aggregation', 'Link Aggregation TLV',
-        LinkAggregationPropertyParser()),
-    # Tlv(0x7f, OUI.IEEE8023, 3, 'Link Aggregation', 'Link Aggregation TLV',
-    #    LinkAggregationPropertyParser()),
-    Tlv(0x7f, OUI.IEEE8023, 4, 'MTU', 'Maximum Frame Size TLV',
-        SingleStringPropertyParser()),
-])
+TLVS = frozenset(
+    [
+        Tlv(1, 0, 0, 'Chassis ID', 'Chassis ID TLV', ChassisIdParser()),
+        Tlv(2, 0, 0, 'Port ID', 'Port ID TLV', PortIdParser()),
+        Tlv(
+            3,
+            0,
+            0,
+            'Time to Live',
+            'Time to Live TLV',
+            SingleStringPropertyParser(),
+        ),
+        Tlv(
+            4,
+            0,
+            0,
+            'Port Description',
+            'Port Description TLV',
+            SingleStringPropertyParser(),
+        ),
+        Tlv(
+            5,
+            0,
+            0,
+            'System Name',
+            'System Name TLV',
+            SingleStringPropertyParser(),
+        ),
+        Tlv(
+            6,
+            0,
+            0,
+            'System Description',
+            'System Description TLV',
+            SingleStringPropertyParser(),
+        ),
+        Tlv(
+            7,
+            0,
+            0,
+            'System Capabilities',
+            'System Capabilities TLV',
+            MultiStringPropertyParser(),
+        ),
+        Tlv(
+            8,
+            0,
+            0,
+            'Management Address',
+            'Management Address TLV',
+            ManagmentAddressParser(),
+        ),
+        Tlv(
+            0x7F,
+            OUI.IEEE8021,
+            1,
+            'Port VLAN ID',
+            'Port VLAN ID TLV',
+            PortVlanIdParser(),
+        ),
+        Tlv(
+            0x7F,
+            OUI.IEEE8021,
+            3,
+            'VLAN Name',
+            'VLAN Name TLV',
+            VlanNameParser(),
+        ),
+        # Because lldptool shows both Link Aggregation TLV in the same way,
+        # it is not possible to conclude from lldptool's output to the OUI and
+        # subtype. Here the Link Aggregation TLV is mapped to the IEEE8021
+        # Organizationally Specific TLV.
+        Tlv(
+            0x7F,
+            OUI.IEEE8021,
+            7,
+            'Link Aggregation',
+            'Link Aggregation TLV',
+            LinkAggregationPropertyParser(),
+        ),
+        # Tlv(0x7f, OUI.IEEE8023, 3, 'Link Aggregation', 'Link Aggregation TLV'
+        #    LinkAggregationPropertyParser()),
+        Tlv(
+            0x7F,
+            OUI.IEEE8023,
+            4,
+            'MTU',
+            'Maximum Frame Size TLV',
+            SingleStringPropertyParser(),
+        ),
+    ]
+)
 
 TLVS_BY_DESCRIPTION = {tlv.description: tlv for tlv in TLVS}
