@@ -23,12 +23,14 @@ from __future__ import absolute_import
 import os
 import logging
 import threading
+import time
 from collections import namedtuple
 import codecs
 from contextlib import contextmanager
 
 import six
 
+from vdsm import host
 from vdsm import utils
 from vdsm.common import exception
 from vdsm.common.marks import deprecated
@@ -39,6 +41,7 @@ from vdsm.storage import clusterlock
 from vdsm.storage import constants as sc
 from vdsm.storage import exception as se
 from vdsm.storage import fileUtils
+from vdsm.storage import guarded
 from vdsm.storage import misc
 from vdsm.storage import outOfProcess as oop
 from vdsm.storage import qemuimg
@@ -47,7 +50,11 @@ from vdsm.storage import resourceManager as rm
 from vdsm.storage import rwlock
 from vdsm.storage import sanlock_direct
 from vdsm.storage import task
+from vdsm.storage import utils as su
+from vdsm.storage import validators
 from vdsm.storage import xlease
+from vdsm.storage.sdc import sdCache
+
 from vdsm.storage.persistent import unicodeEncoder, unicodeDecoder
 
 DOMAIN_META_DATA = 'dom_md'
@@ -776,6 +783,58 @@ class StorageDomainManifest(object):
             with self.external_leases_volume() as vol:
                 return vol.lookup(lease_id)
 
+    def lease_status(self, lease_id, host_id):
+        """
+        Return the status of an external lease, indicating whether it is
+        currently held.
+
+        Returns:
+            A dict containing information about the lease, such as:
+            owners - A list of host ids holding the lease
+            version - The version of the host, a lease's owner isa combination
+                      of a host id and a version (controlled by sanlock)
+            metadata - The lvb data stored on the lease.
+
+        """
+        lease_info = self.lease_info(lease_id)
+        lease = clusterlock.Lease(
+            lease_info.resource,
+            lease_info.path,
+            lease_info.offset)
+
+        # Failing here will raise an exception, this expected as we cannot
+        # tell anything about the status of the lease if we couldn't inquire
+        # it.
+        res_version, owner_host_id = self._domainLock.inquire(lease)
+        lvb = None
+
+        # We only care about reading lvb on released leases, as lvb is written
+        # when the lease is released and we'll fail to acquire the lease if
+        # it's held anyway.
+        if owner_host_id is None:
+            try:
+                self.acquire_external_lease(lease_id, host_id)
+            except se.AcquireLockFailure:
+                self.log.warn("Could not acquire lease %s", lease_id)
+                # lease is currently held, return lease info without lvb
+            else:
+                try:
+                    lvb = self.get_lvb(lease_id)
+                finally:
+                    self.release_external_lease(lease_id)
+
+        owners = [owner_host_id] if owner_host_id is not None else []
+
+        response = {
+            "owners": owners,
+            "version": res_version,
+        }
+
+        if lvb is not None:
+            response["metadata"] = lvb
+
+        return response
+
     def set_lvb(self, lease_id, info):
         """
         Write LVB data for lease.
@@ -811,6 +870,67 @@ class StorageDomainManifest(object):
 
         return self._domainLock.get_lvb(lease)
 
+    def fence_lease(self, lease_id, host_id, metadata):
+        """
+        Fence a lease by updating the metadata based on the job status:
+        * If the job is no longer running - If the lease is free, the job
+          status is PENDING and the generation is correct, we can safely
+          change the job status to FENCED and bump the generation.
+        * If the job is still running, we will fail to acquire the lease,
+          a sanlock error will be raised.
+        * If the lease is free but the job is in a status other than PENDING
+          (SUCCEEDED, FAILED), JobStatusMismatch will be raised.
+
+        Arguments:
+            lease_id (str): uuid of the lease.
+            host_id (int): the id of the host attempting to fence.
+            metadata (dict): expected lease metadata.
+        """
+
+        lease_info = self.lease_info(lease_id)
+        lease = clusterlock.Lease(
+            lease_info.resource,
+            lease_info.path,
+            lease_info.offset)
+        self.acquire_external_lease(lease_id, host_id)
+        try:
+            current_metadata = self.get_lvb(lease_id)
+            self.log.info(
+                "Current lease %s metadata: %r", lease_id, metadata)
+
+            if current_metadata.get("type") != metadata.type:
+                raise se.UnsupportedOperation(
+                    "job type doesn't match supported type",
+                    expected=metadata.type,
+                    actual=current_metadata.get("type"))
+
+            if current_metadata.get("job_id") != metadata.job_id:
+                raise se.UnsupportedOperation(
+                    "job_id on lease doesn't match passed job_id",
+                    exptected=metadata.job_id,
+                    actual=current_metadata.get("job_id"))
+
+            if current_metadata.get("job_status") != metadata.job_status:
+                raise se.JobStatusMismatch(
+                    metadata.job_status, current_metadata.get("job_status"))
+
+            if current_metadata.get("generation") != metadata.generation:
+                raise se.GenerationMismatch(
+                    metadata.generation, current_metadata.get("generation"))
+
+            updated_metadata = current_metadata.copy()
+            updated_metadata["modified"] = int(time.time())
+            updated_metadata["host_hardware_id"] = host.uuid()
+            updated_metadata["generation"] = \
+                su.next_generation(metadata.generation)
+            updated_metadata["job_status"] = sc.JOB_STATUS_FENCED
+
+            self.log.info(
+                "Writing data to lease %s: %r", lease_id, updated_metadata)
+            self._domainLock.set_lvb(lease, updated_metadata)
+        finally:
+            self.release_external_lease(lease_id)
+
 
 class StorageDomain(object):
     log = logging.getLogger("storage.StorageDomain")
@@ -1501,7 +1621,7 @@ class StorageDomain(object):
         """
         raise NotImplementedError
 
-    def create_lease(self, lease_id):
+    def create_lease(self, lease_id, metadata=None, host_id=None):
         """
         Create an external lease on the external leases volume.
 
@@ -1511,6 +1631,27 @@ class StorageDomain(object):
             with self._manifest.external_leases_volume() as vol:
                 vol.add(lease_id)
 
+        if metadata:
+            metadata = validators.JobMetadata(metadata)
+
+            self._manifest.acquire_external_lease(lease_id, host_id)
+
+            try:
+                now = int(time.time())
+                job_metadata = {
+                    "type": metadata.type,
+                    "generation": metadata.generation,
+                    "job_id": metadata.job_id,
+                    "job_status": metadata.job_status,
+                    "created": now,
+                    "modified": now,
+                    "host_hardware_id": host.uuid(),
+                }
+
+                self._manifest.set_lvb(lease_id, job_metadata)
+            finally:
+                self._manifest.release_external_lease(lease_id)
+
     def delete_lease(self, lease_id):
         """
         Delete an external lease on the external leases volume.
@@ -1645,3 +1786,31 @@ class StorageDomain(object):
             size=self.alignment,
             block_size=self.block_size,
             alignment=self.alignment))
+
+
+class ExternalLease(guarded.AbstractLock):
+
+    def __init__(self, host_id, sd_id, lease_id):
+        self._host_id = host_id
+        self._sd_id = sd_id
+        self._lease_id = lease_id
+
+    @property
+    def ns(self):
+        return rm.getNamespace(sc.EXTERNAL_LEASE_NAMESPACE, self._lease_id)
+
+    @property
+    def name(self):
+        return self._lease_id
+
+    @property
+    def mode(self):
+        return rm.EXCLUSIVE
+
+    def acquire(self):
+        dom = sdCache.produce_manifest(self._sd_id)
+        dom.acquire_external_lease(self._lease_id, self._host_id)
+
+    def release(self):
+        dom = sdCache.produce_manifest(self._sd_id)
+        dom.release_external_lease(self._lease_id)
